### Usage and Installation
```
pip3 install install ndp-app-deployment==1.5

from ndp_deployment.fetch_metastore import object_deployment

object_deployment(api_url,user_email,user_password,folder_path,option_for_backup,container_name,object_name)
```